--
-- Projet: offreformation
--
-- Licensed under the Apache License, Version 2.0 (the "License");
-- you may not use this file except in compliance with the License.
-- You may obtain a copy of the License at
--
--         http://www.apache.org/licenses/LICENSE-2.0
--
-- Unless required by applicable law or agreed to in writing, software
-- distributed under the License is distributed on an "AS IS" BASIS,
-- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-- See the License for the specific language governing permissions and
-- limitations under the License.
--

CREATE TABLE COURS (
  ID_COURS                          BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY,
  LIBELLE_COURT                     VARCHAR(120)    DEFAULT '',
  LIBELLE_LONG                      TEXT,
  CREDIT_ECTS                       VARCHAR(4)      DEFAULT '',
  DISCIPLINE                        TEXT,
  CODE_RATTACHEMENT_AUTRES          TEXT,
  CODE_RESPONSABLE                  TEXT,
  COMPLEMENTS_RESPONSABLE           TEXT,
  COORDONNEES                       TEXT,
  VOLUME_HORAIRE_CM                 VARCHAR(6)      DEFAULT '',
  VOLUME_HORAIRE_TD                 VARCHAR(6)      DEFAULT '',
  VOLUME_HORAIRE_TP                 VARCHAR(6)      DEFAULT '',
  VOLUME_HORAIRE_PROJET             VARCHAR(6)      DEFAULT '',
  VOLUME_HORAIRE_STAGE              VARCHAR(6)      DEFAULT '',
  VOLUME_HORAIRE_DS                 VARCHAR(6)      DEFAULT '',
  COEF_TP                           VARCHAR(6)      DEFAULT '',
  COEF_DS                           VARCHAR(6)      DEFAULT '',
  OBJECTIFS                         TEXT,
  CALENDRIER                        TEXT,
  CONTENU                           TEXT,
  BIBLIOGRAPHIE                     TEXT,
  CONTROLE_CONNAISSANCES            TEXT,
  COMPLEMENTS                       TEXT,
  RATTACHEMENT_BANDEAU              VARCHAR(1)      DEFAULT '',
  CODE                              VARCHAR(64)     DEFAULT '',
  CODE_RUBRIQUE                     VARCHAR(255)    DEFAULT '',
  CODE_RATTACHEMENT                 VARCHAR(64)     DEFAULT '',
  META_KEYWORDS                     TEXT,
  META_DESCRIPTION                  TEXT,
  TITRE_ENCADRE                     VARCHAR(32)     DEFAULT '',
  CONTENU_ENCADRE                   TEXT,
  ENCADRE_RECHERCHE                 VARCHAR(4)      DEFAULT '',
  ENCADRE_RECHERCHE_BIS             VARCHAR(4)      DEFAULT '',
  DATE_ALERTE                       DATE            DEFAULT NULL,
  MESSAGE_ALERTE                    TEXT,
  DATE_CREATION                     DATETIME        DEFAULT NULL,
  DATE_PROPOSITION                  DATETIME        DEFAULT NULL,
  DATE_VALIDATION                   DATETIME        DEFAULT NULL,
  DATE_MODIFICATION                 DATETIME        DEFAULT NULL,
  CODE_REDACTEUR                    VARCHAR(64)     DEFAULT '',
  CODE_VALIDATION                   VARCHAR(64)     DEFAULT '',
  LANGUE                            VARCHAR(4)      DEFAULT '',
  ETAT_OBJET                        VARCHAR(4)      DEFAULT '',
  NB_HITS                           BIGINT,
  DIFFUSION_PUBLIC_VISE             VARCHAR(255)    DEFAULT '',
  DIFFUSION_MODE_RESTRICTION        VARCHAR(1)      DEFAULT '',
  DIFFUSION_PUBLIC_VISE_RESTRICTION VARCHAR(255)    DEFAULT ''
);

CREATE TABLE FORMATION (
  ID_FORMATION                                BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY,
  LIBELLE_COURT                               VARCHAR(120)    DEFAULT '',
  LIBELLE_LONG                                TEXT,
  FORMATION_LMD                               VARCHAR(1)      DEFAULT '',
  CODE_SISE                                   VARCHAR(30)     DEFAULT '',
  CYCLE                                       VARCHAR(8)      DEFAULT '',
  GRADE                                       VARCHAR(8)      DEFAULT '',
  TYPE_DIPLOME                                TEXT,
  DOMAINE_FORMATION_ETABLISSEMENT             TEXT,
  DISCIPLINE                                  TEXT,
  MENTION                                     TEXT,
  SPECIALITE                                  TEXT,
  CODE_RATTACHEMENT_AUTRES                    TEXT,
  VILLE                                       TEXT,
  AUTRES_ETABLISSEMENTS                       TEXT,
  DIPLOME                                     TINYINT      DEFAULT '',
  NATURE_FORMATION                            VARCHAR(8)      DEFAULT '',
  FORMATION_INITIALE                          TINYINT      DEFAULT '',
  FORMATION_CONTINUE                          TINYINT      DEFAULT '',
  URL_FORMATION_CONTINUE                      VARCHAR(128)    DEFAULT '',
  COMPLEMENTS_FORMATION_CONTINUE              TEXT,
  FORMATION_ALTERNANCE                        TINYINT      DEFAULT '',
  URL_FORMATION_ALTERNANCE                    VARCHAR(128)    DEFAULT '',
  COMPLEMENTS_FORMATION_ALTERNANCE            TEXT,
  FORMATION_APPRENTISSAGE                     TINYINT      DEFAULT '',
  URL_FORMATION_APPRENTISSAGE                 VARCHAR(128)    DEFAULT '',
  COMPLEMENTS_FORMATION_APPRENTISSAGE         TEXT,
  MODALITES_FORMATION_DISTANCE                TINYINT      DEFAULT '',
  URL_FORMATION_DISTANCE                      VARCHAR(128)    DEFAULT '',
  MIXTE_DISTANCE                              TINYINT      DEFAULT '',
  COMPLEMENTS_FORMATION_DISTANCE              TEXT,
  CODE_RESPONSABLES                           TEXT,
  COMPLEMENTS_RESPONSABLES                    TEXT,
  DUREE_ETUDES                                VARCHAR(255)    DEFAULT '',
  RESUME                                      TEXT,
  DESCRIPTION                                 TEXT,
  SPECIFICITES                                TEXT,
  LABORATOIRES_PARTENAIRES                    TEXT,
  ETABLISSEMENTS_PARTENAIRES                  TEXT,
  ENTREPRISES_PARTENAIRES                     TEXT,
  ECHANGES_INTERNATIONAUX                     TEXT,
  DOMAINE_ERASMUS                             TEXT,
  LANGUES_ENSEIGNEMENT                        TEXT,
  NIVEAU_RECRUTEMENT                          TEXT,
  FORMATIONS_REQUISES                         TEXT,
  CODE_FORMATIONS_REQUISES                    TEXT,
  CODE_UEUPS_REQUISES                         TEXT,
  CONDITIONS_ADMISSION                        TEXT,
  INSCRIPTION                                 TEXT,
  TARIF                                       VARCHAR(128)    DEFAULT '',
  CONTACTS                                    TEXT,
  CODE_RESPONSABLES_SCOLARITE                 TEXT,
  COMPLEMENTS_RESPONSABLES_SCOLARITE          TEXT,
  CODE_RESPONSABLES_FORMATION_CONTINUE        TEXT,
  COMPLEMENTS_RESPONSABLES_FORMATION_CONTINUE TEXT,
  PROGRAMME                                   TEXT,
  CONTROLE_CONNAISSANCES                      TEXT,
  JURY_EXAMEN                                 TEXT,
  STAGE_OBLIGATOIRE                           TINYINT      DEFAULT '',
  STAGE_OPTIONNEL                             TINYINT      DEFAULT '',
  STAGE_ETRANGER                              TINYINT      DEFAULT '',
  STAGE                                       TEXT,
  ANNEE_POSTBAC                               VARCHAR(4)      DEFAULT '',
  NIVEAU_SORTIE                               VARCHAR(4)      DEFAULT '',
  POURSUITE_ETUDES                            TEXT,
  COMPETENCES_VISEES                          TEXT,
  COMPLEMENTS_COMPETENCES_VISEES              TEXT,
  DEBOUCHES                                   TEXT,
  SECTEURS_ACTIVITES                          TEXT,
  METIERS                                     TEXT,
  DATE_DEBUT_VALIDITE                         DATE            DEFAULT NULL,
  DATE_FIN_VALIDITE                           DATE            DEFAULT NULL,
  DATE_DEBUT                                  DATE            DEFAULT NULL,
  DATE_FIN                                    DATE            DEFAULT NULL,
  COMPLEMENTS_DATE                            TEXT,
  DOMAINE_FORMATION                           TEXT,
  COMPLEMENTS_VAE                             TEXT,
  STATISTIQUES                                TEXT,
  COMPLEMENTS                                 TEXT,
  RATTACHEMENT_BANDEAU                        VARCHAR(1)      DEFAULT '',
  CODE                                        VARCHAR(64)     DEFAULT '',
  CODE_RUBRIQUE                               VARCHAR(255)    DEFAULT '',
  CODE_RATTACHEMENT                           VARCHAR(64)     DEFAULT '',
  META_KEYWORDS                               TEXT,
  META_DESCRIPTION                            TEXT,
  TITRE_ENCADRE                               VARCHAR(32)     DEFAULT '',
  CONTENU_ENCADRE                             TEXT,
  ENCADRE_RECHERCHE                           VARCHAR(4)      DEFAULT '',
  ENCADRE_RECHERCHE_BIS                       VARCHAR(4)      DEFAULT '',
  DATE_ALERTE                                 DATE            DEFAULT NULL,
  MESSAGE_ALERTE                              TEXT,
  DATE_CREATION                               DATETIME        DEFAULT NULL,
  DATE_PROPOSITION                            DATETIME        DEFAULT NULL,
  DATE_VALIDATION                             DATETIME        DEFAULT NULL,
  DATE_MODIFICATION                           DATETIME        DEFAULT NULL,
  CODE_REDACTEUR                              VARCHAR(64)     DEFAULT '',
  CODE_VALIDATION                             VARCHAR(64)     DEFAULT '',
  LANGUE                                      VARCHAR(4)      DEFAULT '',
  ETAT_OBJET                                  VARCHAR(4)      DEFAULT '',
  NB_HITS                                     BIGINT,
  DIFFUSION_PUBLIC_VISE                       VARCHAR(255)    DEFAULT '',
  DIFFUSION_MODE_RESTRICTION                  VARCHAR(1)      DEFAULT '',
  DIFFUSION_PUBLIC_VISE_RESTRICTION           VARCHAR(255)    DEFAULT '',
  TYPE_FORMATION                              VARCHAR(8)      DEFAULT '',
  CODE_FORMATION_MERE                         VARCHAR(64)     DEFAULT ''
);

CREATE TABLE PARCOURS (
  ID_PARCOURS    BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY,
  LIBELLE        TEXT,
  TYPE           VARCHAR(8)      DEFAULT '',
  LISTE_UEUP     TEXT,
  CODE_FORMATION VARCHAR(30)     DEFAULT '',
  INCREMENT      INTEGER,
  ID_META        BIGINT NOT NULL
);

CREATE TABLE UEUP (
  ID_UEUP                           BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY,
  LIBELLE_COURT                     VARCHAR(120)    DEFAULT '',
  LIBELLE_LONG                      TEXT,
  CREDIT_ECTS                       VARCHAR(4)      DEFAULT '',
  SEMESTRE                          VARCHAR(8)      DEFAULT '',
  TYPE                              VARCHAR(8)      DEFAULT '',
  NATURE                            VARCHAR(8)      DEFAULT '',
  NB_MAXI_ACHOIX                    VARCHAR(4)      DEFAULT '',
  NB_MINI_ACHOIX                    VARCHAR(4)      DEFAULT '',
  DISCIPLINES                       TEXT,
  CODE_RATTACHEMENT_AUTRES          TEXT,
  VILLE                             TEXT,
  A_DISTANCE                        VARCHAR(1)      DEFAULT '',
  MIXTE_DISTANCE                    VARCHAR(1)      DEFAULT '',
  CODE_RESPONSABLES                 TEXT,
  COMPLEMENTS_RESPONSABLE           TEXT,
  COORDONNEES                       TEXT,
  VOLUME_HORAIRE_TOTAL              VARCHAR(6)      DEFAULT '',
  VOLUME_HORAIRE_CM                 VARCHAR(6)      DEFAULT '',
  VOLUME_HORAIRE_TD                 VARCHAR(6)      DEFAULT '',
  VOLUME_HORAIRE_TP                 VARCHAR(6)      DEFAULT '',
  VOLUME_HORAIRE_PROJET             VARCHAR(6)      DEFAULT '',
  VOLUME_HORAIRE_STAGE              VARCHAR(6)      DEFAULT '',
  VOLUME_HORAIRE_DS                 VARCHAR(6)      DEFAULT '',
  VOLUME_HORAIRE_FORMATION_DISTANCE VARCHAR(6)      DEFAULT '',
  VOLUME_HORAIRE_PRESENTIEL         VARCHAR(6)      DEFAULT '',
  PREREQUIS                         TEXT,
  CODE_UEUPS_REQUISES               TEXT,
  OBJECTIFS                         TEXT,
  CALENDRIER                        TEXT,
  CONTENU                           TEXT,
  CODE_UEUPFILS                     TEXT,
  CODE_COURS                        TEXT,
  BIBLIOGRAPHIE                     TEXT,
  CONTROLE_CONNAISSANCES            TEXT,
  DOMAINES                          TEXT,
  DOMAINE_ERASMUS                   TEXT,
  GRADE                             VARCHAR(8)      DEFAULT '',
  TYPE_DIPLOME                      VARCHAR(8)      DEFAULT '',
  LANGUES_ENSEIGNEMENT              TEXT,
  COMPLEMENTS                       TEXT,
  RATTACHEMENT_BANDEAU              VARCHAR(1)      DEFAULT '',
  CODE                              VARCHAR(64)     DEFAULT '',
  CODE_RUBRIQUE                     VARCHAR(255)    DEFAULT '',
  CODE_RATTACHEMENT                 VARCHAR(64)     DEFAULT '',
  META_KEYWORDS                     TEXT,
  META_DESCRIPTION                  TEXT,
  TITRE_ENCADRE                     VARCHAR(32)     DEFAULT '',
  CONTENU_ENCADRE                   TEXT,
  ENCADRE_RECHERCHE                 VARCHAR(4)      DEFAULT '',
  ENCADRE_RECHERCHE_BIS             VARCHAR(4)      DEFAULT '',
  DATE_ALERTE                       DATE            DEFAULT NULL,
  MESSAGE_ALERTE                    TEXT,
  DATE_CREATION                     DATETIME        DEFAULT NULL,
  DATE_PROPOSITION                  DATETIME        DEFAULT NULL,
  DATE_VALIDATION                   DATETIME        DEFAULT NULL,
  DATE_MODIFICATION                 DATETIME        DEFAULT NULL,
  CODE_REDACTEUR                    VARCHAR(64)     DEFAULT '',
  CODE_VALIDATION                   VARCHAR(64)     DEFAULT '',
  LANGUE                            VARCHAR(4)      DEFAULT '',
  ETAT_OBJET                        VARCHAR(4)      DEFAULT '',
  NB_HITS                           BIGINT,
  DIFFUSION_PUBLIC_VISE             VARCHAR(255)    DEFAULT '',
  DIFFUSION_MODE_RESTRICTION        VARCHAR(1)      DEFAULT '',
  DIFFUSION_PUBLIC_VISE_RESTRICTION VARCHAR(255)    DEFAULT ''
);